@extends('adminlte::page')

@section('content')

@section('content_header', __('admin.edit_article'))

<!-- box -->
<div class="row">

    <!-- col -->
    <div class="col-md-12">

        @if(count($errors) > 0)
        <div class="alert alert-danger">
            @foreach($errors->all() as $error)
            <p><i class="fas fa-minus-circle"></i> {{$error}}</p>
            @endforeach
        </div>
        @endif @if(Session::has('success'))
        <div class="alert alert-success">
            <p><i class="fas fa-check-circle"></i> {{ Session::get('success') }}</p>
        </div>
        @endif

        <!-- general form elements -->
        <div class="box">

            <!-- form -->
            <form method="POST" enctype="multipart/form-data" action="{{action('App\Http\Controllers\ArticleController@update', $id)}}">
                @csrf @method('PUT')

                <!-- box-body -->
                <div class="box-body">

                    <!-- row -->
                    <div class="row">

                        <div class="col-md-4">
                            <div class="form-group">
                                <label>@lang('admin.language') <span class="text-danger">*</span></label>
                                <select title="@lang('admin.select_language')" name="language" class="form-control selectpicker" data-live-search="true">
                                    @foreach($translations as $translation)
                                    <option value="{{ $translation->id }}" data-content="<span class='fi fi-{{$translation['icon']}}'></span> {{$translation['language']}}" {{ $article->language == $translation->id ? ' selected' : '' }}></option>
                                    @endforeach
                                </select>
                            </div>
                        </div>

                    </div>
                    <!-- /.row -->

                    <div class="form-group">
                        <label>@lang('admin.title') <span class="text-danger">*</span></label>
                        <input type="text" name="title" class="form-control" value="{{$article->title}}" placeholder="@lang('admin.title')" />
                    </div>

                    <div class="form-group">
                        <label>@lang('admin.slug')</label>
                        <input type="text" name="slug" class="form-control" value="{{$article->slug}}" placeholder="@lang('admin.slug')" />
                    </div>

                    <div class="form-group">
                        <label>@lang('admin.description') <span class="text-danger">*</span></label>
                        <textarea class="form-control textarea-h-100" name="description" rows="4" placeholder="@lang('admin.description')">{{$article->description}}</textarea>
                    </div>

                    <div class="form-group">
                        <label>@lang('admin.content') <span class="text-danger">*</span></label>
                        <textarea class="textarea textarea-style" name="details" placeholder="@lang('admin.content')">{{$article->details}}</textarea>
                    </div>

                    <div class="form-group clearfix">
                        <a href="{{ asset('images/articles') }}/{{ $article->image }}" data-toggle="lightbox"><img src="{{ asset('images/articles') }}/{{ $article->image }}" class="img-responsive article-image"></a>
                        <label>@lang('admin.image')</label><br />
                        <label class="btn btn-outline btn-sm" id="browse-color-image">@lang('admin.browse')<input type="file" name="image" id="import-file-select" class="hidden"></label>
                    </div>

                    <hr class="divider" />

                    <!-- row -->
                    <div class="row">

                        <div class="col-md-12">
                            <label class="section-head">@lang('admin.seo_settings')</label>
                        </div>

                    </div>
                    <!-- /.row -->

                    <div class="form-group">
                        <label>@lang('admin.custom_title')</label>
                        <input type="text" name="custom_title" class="form-control" value="{{$article->custom_title}}" placeholder="@lang('admin.custom_title')" />
                    </div>

                    <div class="form-group">
                        <label>@lang('admin.custom_description')</label>
                        <textarea class="form-control" name="custom_description" rows="3" placeholder="@lang('admin.custom_description')">{{$article->custom_description}}</textarea>
                    </div>

                </div>
                <!-- /.box-body -->

                <div class="box-footer">
                    <button type="submit" class="btn btn-primary">@lang('admin.submit')</button>
                </div>

            </form>
            <!-- /.form -->

        </div>
        <!-- /.general form elements -->

    </div>
    <!-- /.col -->

</div>
<!-- /.box -->

@endsection